ApmKitName class

Constructors

ApmKitName()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

kitCarsh → const String
kitChannel → const String
kitFps → const String
kitHttp → const String
kitLog → const String
kitMemory → const String
kitPageLaunch → const String
kitRoute → const String
kitSourceCode → const String