CrashLogManager class

Properties

crashSwitch ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
listener ↔ Function?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addException(String exception) → void
addLog(int type, String msg) → void
getLogs() → List<IInfo>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerListener(Function listener) → void
toString() → String
A string representation of this object.
inherited
unregisterListener() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → CrashLogManager
no setter