FpsKit class

Inheritance

Constructors

FpsKit()

Properties

hashCode int
The hash code for this object.
no setterinherited
lastFrame int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storage IStorage
getter/setter pairinherited

Methods

checkValid(int fps) bool
createDisplayPage() Widget
override
createStorage() IStorage
override
delete(int index) bool
inherited
edit(int index, IInfo info) bool
inherited
getIcon() String
override
getKitName() String
override
getStorage() IStorage
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllItem() bool
inherited
save(IInfo? info) bool
inherited
start() → void
override
stop() → void
override
tabAction() → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited