HttpInfo1 class

Implemented types

Constructors

HttpInfo1(Uri? uri, String method, String requestId, {bool isMock = false})

Properties

error ↔ String?
getter/setter pair
expand ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isMock ↔ bool
getter/setter pair
method → String
final
request ↔ HttpRequest
getter/setter pair
requestId → String
final
response ↔ HttpResponse?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTimestamp → int
final
uri → Uri?
final

Methods

getValue() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited