HttpKit class

Inheritance

Constructors

HttpKit()

Properties

hashCode → int
The hash code for this object.
no setterinherited
listener ↔ Function?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storage ↔ IStorage
getter/setter pairinherited

Methods

createDisplayPage() → Widget
override
createStorage() → IStorage
override
delete(int index) → bool
inherited
edit(int index, IInfo info) → bool
inherited
getIcon() → String
override
getKitName() → String
override
getStorage() → IStorage
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerListener(Function listener) → void
removeAllItem() → bool
inherited
save(IInfo? info) → bool
inherited
start() → void
override
stop() → void
override
tabAction() → void
inherited
toString() → String
A string representation of this object.
inherited
unregisterListener() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited