MockLocalTool class

Constructors

MockLocalTool()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

compareDataByParamType(String data, ParamType paramType, dynamic body) bool
compareList(List arr1, List arr2) bool
editData() Future
mapContainEqual(Map json1, Map json2) bool
parseMockData(RequestOptions options) → Response?
parseStringByParamType(String data, ParamType paramType) → dynamic