MethodChannelDoraemonkitCsx class

An implementation of DoraemonkitCsxPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
override
getUserDefaults() Future<Map>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openAndroidDeveloperOptions() Future
override
openAndroidLocalLanguagesPage() Future<bool>
override
openiOSSettingPage() Future<bool>
override
setUserDefault(Map<String, dynamic> tempJson) Future
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited