DoraemonkitCsxPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • DoraemonkitCsxPlatform
Implementers

Constructors

DoraemonkitCsxPlatform()
Constructs a DoraemonkitCsxPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
getUserDefaults() Future<Map>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openAndroidDeveloperOptions() Future
openAndroidLocalLanguagesPage() Future<bool>
openiOSSettingPage() Future<bool>
setUserDefault(Map<String, dynamic> tempJson) Future
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DoraemonkitCsxPlatform
The default instance of DoraemonkitCsxPlatform to use.
getter/setter pair