CommonKitName class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- kitBaseClearcache → const String
- kitBaseDevoptions → const String
- kitBaseH5 → const String
- kitBaseInfo → const String
- kitBaseLanguage → const String
- kitBaseLocation → const String
- kitBaseQR → const String
- kitBaseSandbox → const String
- kitBaseSetting → const String
- kitBaseUserDefaults → const String