CsxDokit class

Constructors

CsxDokit()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

i → _DoKitInterfaces
暴露出来的除run外的所有接口
final

Static Methods

run({DoKitApp? app, bool useRunZoned = true, Future<IDoKitApp> appCreator()?, bool useInRelease = false, dynamic logCallback(String)?, dynamic exceptionCallback(dynamic, StackTrace)?, List<String> methodChannelBlackList = const <String>[], VoidCallback? releaseAction}) → dynamic