CsxKitShare class

Constructors

CsxKitShare()
factory

Properties

areaPadding EdgeInsets
no setter
doCustomCallMap Map<DokitCallType, CustomCallback>?
no setter
hashCode int
The hash code for this object.
no setterinherited
no setter
overlayContext BuildContext?
no setter
overlayState OverlayState
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenSize Size
no setter
showMenuNotifier ValueNotifier<bool>
no setter

Methods

close() → void
退出处理
hiddenMenu() → void
init(dynamic toastCall(String), dynamic printLogCall(String), BuildContext context, GlobalKey<NavigatorState> navigatorKey, {Map<DokitCallType, CustomCallback>? customCallMap}) → void
使用初始化
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printLog(String msg) → void
showDetailPage() → void
showMenu() → void
toast(String msg) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance CsxKitShare
no setter