CommonStorage class

Implemented types

Constructors

CommonStorage({int maxCount = 100})

Properties

hashCode → int
The hash code for this object.
no setterinherited
items ↔ Queue<IInfo>
getter/setter pair
maxCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
override
contains(IInfo info) → bool
override
delete(int index) → bool
override
edit(int index, IInfo info) → bool
override
getAll() → List<IInfo>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(IInfo info) → bool
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited