SandBoxModel class

Constructors

SandBoxModel({String name = '', String path = '', num byte = 0, FileType? fileType, List<SandBoxModel>? childrens})

Properties

byte num
getter/setter pair
byteStr String
no setter
childrens List<SandBoxModel>?
getter/setter pair
fileType FileType?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
path String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited