SPService class

Constructors

SPService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<bool>
清空所有缓存数据;清除缓存的stream;关闭streamController
containsKey(String key) Future<bool>
get<T>(String key, T defaultValue) Future<T>
根据默认值的类型获取对应类型的值
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) Future<bool>
移除key对应的值;清除缓存的stream
set<T>(String key, T value) Future<bool>
根据value的类型调用设置方法
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance SPService
getter/setter pair