BoxDecorationPainter class

An object that paints a DashedDecoration into a canvas.

Inheritance

Constructors

BoxDecorationPainter(DashedDecoration _decoration, VoidCallback? onChanged)

Properties

hashCode int
The hash code for this object.
no setterinherited
onChanged VoidCallback?
Callback that is invoked if an asynchronously-loading resource used by the decoration finishes loading. For example, an image. When this is invoked, the paint method should be called again.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Discard any resources being held by the object.
override
getDashedPath({required Point<double> a, required Point<double> b, required num gap}) Path
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Offset offset, ImageConfiguration configuration) → void
Paint the box decoration into the given location on the given canvas
override
shouldRepaint(CustomPainter oldDelegate) bool
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited