HttpRequest class

Constructors

HttpRequest({Map<String, dynamic>? header, Map<String, dynamic>? body, Map<String, dynamic>? queryParameters})

Properties

body Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
final
queryParameters Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited