HttpResponse class
Constructors
-
HttpResponse({int? statusCode, dynamic data, Map<
String, dynamic> ? header})
Properties
- data → dynamic
-
final
- endTimestamp → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
header
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited