MockModel class
- Implemented types
Constructors
- MockModel(String title, String data, ParamType paramType, bool enable, MockFilterModel filter)
-
MockModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- data ↔ String
-
getter/setter pair
- enable ↔ bool
-
getter/setter pair
- filter ↔ MockFilterModel
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- paramType ↔ ParamType
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String
-
getter/setter pair
Methods
-
getValue(
) → dynamic -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited