VmHelper class
Properties
- allocationProfile ↔ AllocationProfile?
-
getter/setter pair
- connected ↔ bool
-
getter/setter pair
- flutterVersion → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
memoryInfo
↔ Map<
IsolateRef, MemoryUsage> -
getter/setter pair
- packageInfo ↔ PackageInfo?
-
getter/setter pair
-
registeredMethodsForService
→ Map<
String, List< String> > -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceClient ↔ VmService
-
getter/setter pair
-
serviceStreamName
→ Future<
String> -
no setter
- vm ↔ VM?
-
getter/setter pair
Methods
-
callMethod(
String method) → Future< Response> ? -
disConnect(
) → Future< void> -
dumpAllocationProfile(
) → Future< void> -
getDartIOVersion(
String isolateId) → Future< Version> -
handleServiceEvent(
Event e) → void -
isDartIoVersionSupported(
SemanticVersion supportedVersion, String isolateId) → Future< bool> -
isProtocolVersionSupported(
SemanticVersion supportedVersion) → Future< bool> -
isProtocolVersionSupportedNow(
SemanticVersion supportedVersion) → bool -
loadExtensionService(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveFlutterVersion(
) → void -
startConnect(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
updateMemoryUsage(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited