BizKit class
Constructors
Properties
- action → Function?
-
final
- desc → String?
-
final
- group → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
final
- key → String?
-
final
- kitBuilder → KitPageBuilder?
-
final
- kitPageBuilder → KitPageBuilder?
-
no setter
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
displayPage(
) → Widget? - 返回BizKit 绑定的widget页面 如有的话,否则返回null
-
getIcon(
) → String -
override
-
getKitName(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tabAction(
) → void -
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited