ElementUtil class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
checkSelected(
RenderObjectElement? last, RenderObjectElement current, Offset buttonOffset) → bool -
getOverlayPercent(
RenderObjectElement element, Offset buttonOffset) → double -
isOverlap(
Rect rc1, Rect rc2) → bool -
resolveTree(
Offset buttonOffset, BuildContext context) → RenderObjectElement? -
toInfoString(
RenderObjectElement element) → String